@@ -19,7 +19,7 @@ class TimeSeriesSplit(BaseCrossValidator):
         gap (int): Number of time units separating the data used to generate features and the data to forecast on.
             Defaults to 0.
         forecast_horizon (int): Number of time units to forecast. Defaults to 1.
-        date_index (str): Name of the column containing the datetime information used to order the data. Defaults to None.
+        time_index (str): Name of the column containing the datetime information used to order the data. Defaults to None.
         n_splits (int): number of data splits to make. Defaults to 3.
 
     Example:
@@ -53,12 +53,12 @@ class TimeSeriesSplit(BaseCrossValidator):
     """
 
     def __init__(
-        self, max_delay=0, gap=0, forecast_horizon=1, date_index=None, n_splits=3
+        self, max_delay=0, gap=0, forecast_horizon=1, time_index=None, n_splits=3
     ):
         self.max_delay = max_delay
         self.gap = gap
         self.forecast_horizon = forecast_horizon
-        self.date_index = date_index
+        self.time_index = time_index
         self.n_splits = n_splits
         self._splitter = SkTimeSeriesSplit(n_splits=n_splits)
 
