@@ -77,7 +77,7 @@ def test_make_data_splitter_default(problem_type, large_data):
         problem_configuration = {
             "gap": 1,
             "max_delay": 7,
-            "date_index": "foo",
+            "time_index": "foo",
             "forecast_horizon": 4,
         }
 
@@ -118,7 +118,7 @@ def test_make_data_splitter_default(problem_type, large_data):
         assert data_splitter.gap == 1
         assert data_splitter.max_delay == 7
         assert data_splitter.forecast_horizon == 4
-        assert data_splitter.date_index == "foo"
+        assert data_splitter.time_index == "foo"
 
 
 @pytest.mark.parametrize(
@@ -158,7 +158,7 @@ def test_make_data_splitter_parameters_time_series():
             X,
             y,
             problem_type,
-            problem_configuration={"gap": 1, "max_delay": 7, "date_index": "foo"},
+            problem_configuration={"gap": 1, "max_delay": 7, "time_index": "foo"},
             n_splits=5,
             shuffle=False,
         )
@@ -166,7 +166,7 @@ def test_make_data_splitter_parameters_time_series():
         assert data_splitter.n_splits == 5
         assert data_splitter.gap == 1
         assert data_splitter.max_delay == 7
-        assert data_splitter.date_index == "foo"
+        assert data_splitter.time_index == "foo"
 
 
 def test_make_data_splitter_error():
@@ -323,7 +323,9 @@ def test_get_pipelines_from_component_graphs(problem_type, estimator):
         },
     }
     if problem_type == "time series regression":
-        with pytest.raises(ValueError, match="date_index, gap, and max_delay"):
+        with pytest.raises(
+            ValueError, match="time_index, gap, max_delay, and forecast_horizon"
+        ):
             get_pipelines_from_component_graphs(component_graphs, problem_type)
     else:
         returned_pipelines = get_pipelines_from_component_graphs(
