@@ -52,8 +52,28 @@ def test_search_iterative_data_check_error(
     pd.testing.assert_series_equal(target, infer_feature_types(y))
 
 
+def test_n_splits_passed_to_ts_splitting_data_check(ts_data):
+    X = pd.DataFrame(pd.date_range("1/1/21", periods=100), columns=["date"])
+    y = pd.Series(0 if i < 40 else 1 for i in range(100))
+
+    problem_config = {
+        "gap": 1,
+        "max_delay": 1,
+        "forecast_horizon": 1,
+        "time_index": "date",
+    }
+    _, data_checks = search_iterative(
+        X_train=X,
+        y_train=y,
+        problem_configuration=problem_config,
+        problem_type="time series binary",
+        n_splits=4,
+    )
+    assert len(data_checks["errors"][0]["details"]["invalid_splits"]) == 4
+
+
 @pytest.mark.parametrize(
-    "problem_config", [None, "missing_date_index", "has_date_index"]
+    "problem_config", [None, "missing_time_index", "missing_other_index"]
 )
 def test_search_iterative_data_check_error_timeseries(problem_config):
     X, y = pd.DataFrame({"features": range(30)}), pd.Series(range(30))
@@ -64,39 +84,23 @@ def test_search_iterative_data_check_error_timeseries(problem_config):
     )
     X["dates"] = dates
 
-    if problem_config == "missing_date_index":
+    if not problem_config:
+        problem_configuration = None
+    elif problem_config == "missing_time_index":
         problem_configuration = {"gap": 4}
-        with pytest.raises(
-            ValueError,
-            match="date_index has to be passed in problem_configuration.",
-        ):
-            search_iterative(
-                X_train=X,
-                y_train=y,
-                problem_type="time series regression",
-                problem_configuration=problem_configuration,
-            )
-    elif not problem_config:
-        with pytest.raises(
-            ValueError,
-            match="the problem_configuration parameter must be specified.",
-        ):
-            search_iterative(
-                X_train=X,
-                y_train=y,
-                problem_type="time series regression",
-                problem_configuration=problem_configuration,
-            )
-    else:
-        problem_configuration = {"date_index": "dates"}
-        automl, data_check_results = search_iterative(
+    elif problem_config == "missing_other_index":
+        problem_configuration = {"time_index": "dates", "max_delay": 2, "gap": 2}
+
+    with pytest.raises(
+        ValueError,
+        match="problem_configuration must be a dict containing",
+    ):
+        search_iterative(
             X_train=X,
             y_train=y,
             problem_type="time series regression",
             problem_configuration=problem_configuration,
         )
-        assert len(data_check_results["warnings"]) == 1
-        assert len(data_check_results["errors"]) == 1
 
 
 @patch("evalml.data_checks.default_data_checks.DefaultDataChecks.validate")
