@@ -4,14 +4,13 @@ import numpy as np
 import pandas as pd
 import pytest
 from pandas.testing import assert_frame_equal
-from pytest import importorskip
 
 from evalml.model_family import ModelFamily
 from evalml.pipelines import LightGBMRegressor
 from evalml.problem_types import ProblemTypes
 from evalml.utils import SEED_BOUNDS
 
-lgbm = importorskip("lightgbm", reason="Skipping test because lightgbm not installed")
+pytestmark = pytest.mark.noncore_dependency
 
 
 def test_model_family():
@@ -42,7 +41,8 @@ def test_lightgbm_regressor_random_seed_bounds_seed(X_y_regression):
     clf.fit(X, y)
 
 
-def test_fit_predict_regression(X_y_regression):
+def test_fit_predict_regression(X_y_regression, lgbm):
+
     X, y = X_y_regression
 
     sk_clf = lgbm.sklearn.LGBMRegressor(n_estimators=20, random_state=0)
@@ -56,7 +56,8 @@ def test_fit_predict_regression(X_y_regression):
     np.testing.assert_almost_equal(y_pred_sk, y_pred.values, decimal=5)
 
 
-def test_feature_importance(X_y_regression):
+def test_feature_importance(X_y_regression, lgbm):
+
     X, y = X_y_regression
 
     clf = LightGBMRegressor()
@@ -70,7 +71,8 @@ def test_feature_importance(X_y_regression):
     np.testing.assert_almost_equal(sk_feature_importance, feature_importance, decimal=3)
 
 
-def test_fit_string_features(X_y_regression):
+def test_fit_string_features(X_y_regression, lgbm):
+
     X, y = X_y_regression
     X = pd.DataFrame(X)
     X["string_col"] = "abc"
@@ -174,7 +176,8 @@ def test_multiple_fit(mock_predict):
     assert_frame_equal(X2_predict_expected, mock_predict.call_args[0][0])
 
 
-def test_regression_rf(X_y_regression):
+def test_regression_rf(X_y_regression, lgbm):
+
     X, y = X_y_regression
 
     with pytest.raises(lgbm.basic.LightGBMError, match="bagging_fraction"):
