@@ -44,7 +44,11 @@ def test_data_check_message_attributes(data_check_message):
     assert data_check_message.data_check_name == "test data check message name"
     assert data_check_message.message_type is None
     assert data_check_message.message_code == DataCheckMessageCode.HIGHLY_NULL_COLS
-    assert data_check_message.details == {"message detail": "some message detail"}
+    assert data_check_message.details == {
+        "message detail": "some message detail",
+        "columns": None,
+        "rows": None,
+    }
 
 
 def test_data_check_message_str(data_check_message):
@@ -71,7 +75,11 @@ def test_data_check_warning_attributes(data_check_warning):
     assert data_check_warning.data_check_name == "test data check warning name"
     assert data_check_warning.message_type == DataCheckMessageType.WARNING
     assert data_check_warning.message_code == DataCheckMessageCode.HIGHLY_NULL_COLS
-    assert data_check_warning.details == {"warning detail": "some warning detail"}
+    assert data_check_warning.details == {
+        "warning detail": "some warning detail",
+        "columns": None,
+        "rows": None,
+    }
 
 
 def test_data_check_warning_str(data_check_warning):
@@ -98,7 +106,11 @@ def test_data_check_error_attributes(data_check_error):
     assert data_check_error.data_check_name == "test data check error name"
     assert data_check_error.message_type == DataCheckMessageType.ERROR
     assert data_check_error.message_code == DataCheckMessageCode.HIGHLY_NULL_COLS
-    assert data_check_error.details == {"error detail": "some error detail"}
+    assert data_check_error.details == {
+        "error detail": "some error detail",
+        "columns": None,
+        "rows": None,
+    }
 
 
 def test_data_check_error_str(data_check_error):
@@ -128,7 +140,7 @@ def test_data_check_message_attributes_optional():
     assert data_check_warning.data_check_name == "test data check warning name"
     assert data_check_warning.message_type == DataCheckMessageType.WARNING
     assert data_check_warning.message_code is None
-    assert data_check_warning.details is None
+    assert data_check_warning.details == {"columns": None, "rows": None}
 
     data_check_error = DataCheckError(
         message="test error", data_check_name="test data check error name"
@@ -137,7 +149,7 @@ def test_data_check_message_attributes_optional():
     assert data_check_error.data_check_name == "test data check error name"
     assert data_check_error.message_type == DataCheckMessageType.ERROR
     assert data_check_error.message_code is None
-    assert data_check_error.details is None
+    assert data_check_error.details == {"columns": None, "rows": None}
 
 
 def test_warning_error_eq():
@@ -151,27 +163,27 @@ def test_data_check_message_to_dict():
         message="test message",
         data_check_name="same test name",
         message_code=DataCheckMessageCode.HIGHLY_NULL_COLS,
-        details={"detail 1": "error info"},
+        details={"detail 1": "error info", "columns": None, "rows": None},
     )
     assert error.to_dict() == {
         "message": "test message",
         "level": "error",
         "data_check_name": "same test name",
         "code": DataCheckMessageCode.HIGHLY_NULL_COLS.name,
-        "details": {"detail 1": "error info"},
+        "details": {"detail 1": "error info", "columns": None, "rows": None},
     }
     warning = DataCheckWarning(
         message="test message",
         data_check_name="same test name",
         message_code=DataCheckMessageCode.HIGHLY_NULL_COLS,
-        details={"detail 1": "warning info"},
+        details={"detail 1": "warning info", "columns": None, "rows": None},
     )
     assert warning.to_dict() == {
         "message": "test message",
         "level": "warning",
         "data_check_name": "same test name",
         "code": DataCheckMessageCode.HIGHLY_NULL_COLS.name,
-        "details": {"detail 1": "warning info"},
+        "details": {"detail 1": "warning info", "columns": None, "rows": None},
     }
 
 
@@ -181,10 +193,12 @@ def test_data_check_message_to_dict_optional():
         "message": "test message",
         "level": "error",
         "data_check_name": "same test name",
+        "details": {"columns": None, "rows": None},
     }
     warning = DataCheckWarning(message="test message", data_check_name="same test name")
     assert warning.to_dict() == {
         "message": "test message",
         "level": "warning",
         "data_check_name": "same test name",
+        "details": {"columns": None, "rows": None},
     }
