@@ -13,6 +13,17 @@ from evalml.data_checks import (
 highly_null_data_check_name = HighlyNullDataCheck.name
 
 
+@pytest.fixture
+def highly_null_dataframe():
+    return pd.DataFrame(
+        {
+            "lots_of_null": [None, None, None, None, 5],
+            "all_null": [None, None, None, None, None],
+            "no_null": [1, 2, 3, 4, 5],
+        }
+    )
+
+
 class SeriesWrap:
     def __init__(self, series):
         self.series = series
@@ -62,19 +73,12 @@ def test_highly_null_data_check_init():
         HighlyNullDataCheck(pct_null_row_threshold=2.1)
 
 
-def test_highly_null_data_check_warnings():
-    data = pd.DataFrame(
-        {
-            "lots_of_null": [None, None, None, None, 5],
-            "all_null": [None, None, None, None, None],
-            "no_null": [1, 2, 3, 4, 5],
-        }
-    )
+def test_highly_null_data_check_warnings(highly_null_dataframe):
     no_null_check = HighlyNullDataCheck(
         pct_null_col_threshold=0.0, pct_null_row_threshold=0.0
     )
     highly_null_rows = SeriesWrap(pd.Series([2 / 3, 2 / 3, 2 / 3, 2 / 3, 1 / 3]))
-    validate_results = no_null_check.validate(data)
+    validate_results = no_null_check.validate(highly_null_dataframe)
     validate_results["warnings"][0]["details"]["pct_null_cols"] = SeriesWrap(
         validate_results["warnings"][0]["details"]["pct_null_cols"]
     )
@@ -96,20 +100,19 @@ def test_highly_null_data_check_warnings():
                 details={
                     "columns": ["lots_of_null", "all_null"],
                     "pct_null_rows": {"all_null": 1.0, "lots_of_null": 0.8},
-                    "null_row_indices": {
-                        "all_null": [0, 1, 2, 3, 4],
-                        "lots_of_null": [0, 1, 2, 3],
-                    },
                 },
             ).to_dict(),
         ],
         "errors": [],
         "actions": [
             DataCheckAction(
-                DataCheckActionCode.DROP_ROWS, metadata={"rows": [0, 1, 2, 3, 4]}
+                DataCheckActionCode.DROP_ROWS,
+                data_check_name=highly_null_data_check_name,
+                metadata={"rows": [0, 1, 2, 3, 4]},
             ).to_dict(),
             DataCheckAction(
                 DataCheckActionCode.DROP_COL,
+                data_check_name=highly_null_data_check_name,
                 metadata={"columns": ["lots_of_null", "all_null"]},
             ).to_dict(),
         ],
@@ -119,7 +122,7 @@ def test_highly_null_data_check_warnings():
         pct_null_col_threshold=0.5, pct_null_row_threshold=0.5
     )
     highly_null_rows = SeriesWrap(pd.Series([2 / 3, 2 / 3, 2 / 3, 2 / 3]))
-    validate_results = some_null_check.validate(data)
+    validate_results = some_null_check.validate(highly_null_dataframe)
     validate_results["warnings"][0]["details"]["pct_null_cols"] = SeriesWrap(
         validate_results["warnings"][0]["details"]["pct_null_cols"]
     )
@@ -138,20 +141,19 @@ def test_highly_null_data_check_warnings():
                 details={
                     "columns": ["lots_of_null", "all_null"],
                     "pct_null_rows": {"all_null": 1.0, "lots_of_null": 0.8},
-                    "null_row_indices": {
-                        "all_null": [0, 1, 2, 3, 4],
-                        "lots_of_null": [0, 1, 2, 3],
-                    },
                 },
             ).to_dict(),
         ],
         "errors": [],
         "actions": [
             DataCheckAction(
-                DataCheckActionCode.DROP_ROWS, metadata={"rows": [0, 1, 2, 3]}
+                DataCheckActionCode.DROP_ROWS,
+                data_check_name=highly_null_data_check_name,
+                metadata={"rows": [0, 1, 2, 3]},
             ).to_dict(),
             DataCheckAction(
                 DataCheckActionCode.DROP_COL,
+                data_check_name=highly_null_data_check_name,
                 metadata={"columns": ["lots_of_null", "all_null"]},
             ).to_dict(),
         ],
@@ -160,7 +162,7 @@ def test_highly_null_data_check_warnings():
     all_null_check = HighlyNullDataCheck(
         pct_null_col_threshold=1.0, pct_null_row_threshold=1.0
     )
-    assert all_null_check.validate(data) == {
+    assert all_null_check.validate(highly_null_dataframe) == {
         "warnings": [
             DataCheckWarning(
                 message="Columns 'all_null' are 100.0% or more null",
@@ -169,32 +171,26 @@ def test_highly_null_data_check_warnings():
                 details={
                     "columns": ["all_null"],
                     "pct_null_rows": {"all_null": 1.0},
-                    "null_row_indices": {"all_null": [0, 1, 2, 3, 4]},
                 },
             ).to_dict()
         ],
         "errors": [],
         "actions": [
             DataCheckAction(
-                DataCheckActionCode.DROP_COL, metadata={"columns": ["all_null"]}
+                DataCheckActionCode.DROP_COL,
+                data_check_name=highly_null_data_check_name,
+                metadata={"columns": ["all_null"]},
             ).to_dict()
         ],
     }
 
 
-def test_highly_null_data_check_separate_rows_cols():
-    data = pd.DataFrame(
-        {
-            "lots_of_null": [None, None, None, None, 5],
-            "all_null": [None, None, None, None, None],
-            "no_null": [1, 2, 3, 4, 5],
-        }
-    )
+def test_highly_null_data_check_separate_rows_cols(highly_null_dataframe):
     row_null_check = HighlyNullDataCheck(
         pct_null_col_threshold=0.9, pct_null_row_threshold=0.0
     )
     highly_null_rows = SeriesWrap(pd.Series([2 / 3, 2 / 3, 2 / 3, 2 / 3, 1 / 3]))
-    validate_results = row_null_check.validate(data)
+    validate_results = row_null_check.validate(highly_null_dataframe)
     validate_results["warnings"][0]["details"]["pct_null_cols"] = SeriesWrap(
         validate_results["warnings"][0]["details"]["pct_null_cols"]
     )
@@ -213,17 +209,20 @@ def test_highly_null_data_check_separate_rows_cols():
                 details={
                     "columns": ["all_null"],
                     "pct_null_rows": {"all_null": 1.0},
-                    "null_row_indices": {"all_null": [0, 1, 2, 3, 4]},
                 },
             ).to_dict(),
         ],
         "errors": [],
         "actions": [
             DataCheckAction(
-                DataCheckActionCode.DROP_ROWS, metadata={"rows": [0, 1, 2, 3, 4]}
+                DataCheckActionCode.DROP_ROWS,
+                data_check_name=highly_null_data_check_name,
+                metadata={"rows": [0, 1, 2, 3, 4]},
             ).to_dict(),
             DataCheckAction(
-                DataCheckActionCode.DROP_COL, metadata={"columns": ["all_null"]}
+                DataCheckActionCode.DROP_COL,
+                data_check_name=highly_null_data_check_name,
+                metadata={"columns": ["all_null"]},
             ).to_dict(),
         ],
     }
@@ -231,7 +230,7 @@ def test_highly_null_data_check_separate_rows_cols():
     col_null_check = HighlyNullDataCheck(
         pct_null_col_threshold=0.0, pct_null_row_threshold=0.9
     )
-    validate_results = col_null_check.validate(data)
+    validate_results = col_null_check.validate(highly_null_dataframe)
     assert validate_results == {
         "warnings": [
             DataCheckWarning(
@@ -241,10 +240,6 @@ def test_highly_null_data_check_separate_rows_cols():
                 details={
                     "columns": ["lots_of_null", "all_null"],
                     "pct_null_rows": {"lots_of_null": 0.8, "all_null": 1.0},
-                    "null_row_indices": {
-                        "all_null": [0, 1, 2, 3, 4],
-                        "lots_of_null": [0, 1, 2, 3],
-                    },
                 },
             ).to_dict(),
         ],
@@ -252,6 +247,7 @@ def test_highly_null_data_check_separate_rows_cols():
         "actions": [
             DataCheckAction(
                 DataCheckActionCode.DROP_COL,
+                data_check_name=highly_null_data_check_name,
                 metadata={"columns": ["lots_of_null", "all_null"]},
             ).to_dict(),
         ],
@@ -286,17 +282,20 @@ def test_highly_null_data_check_input_formats():
                 details={
                     "columns": [0, 1, 2],
                     "pct_null_rows": {0: 1.0, 1: 1.0, 2: 1.0},
-                    "null_row_indices": {0: [0, 1], 1: [0, 1], 2: [0, 1]},
                 },
             ).to_dict(),
         ],
         "errors": [],
         "actions": [
             DataCheckAction(
-                DataCheckActionCode.DROP_ROWS, metadata={"rows": [0]}
+                DataCheckActionCode.DROP_ROWS,
+                data_check_name=highly_null_data_check_name,
+                metadata={"rows": [0]},
             ).to_dict(),
             DataCheckAction(
-                DataCheckActionCode.DROP_COL, metadata={"columns": [0, 1, 2]}
+                DataCheckActionCode.DROP_COL,
+                data_check_name=highly_null_data_check_name,
+                metadata={"columns": [0, 1, 2]},
             ).to_dict(),
         ],
     }
@@ -326,3 +325,26 @@ def test_highly_null_data_check_input_formats():
         validate_results["warnings"][0]["details"]["pct_null_cols"]
     )
     assert validate_results == expected
+
+
+def test_get_null_column_information(highly_null_dataframe):
+    (
+        highly_null_cols,
+        highly_null_cols_indices,
+    ) = HighlyNullDataCheck.get_null_column_information(
+        highly_null_dataframe, pct_null_col_threshold=0.8
+    )
+    assert highly_null_cols == {"lots_of_null": 0.8, "all_null": 1.0}
+    assert highly_null_cols_indices == {
+        "lots_of_null": [0, 1, 2, 3],
+        "all_null": [0, 1, 2, 3, 4],
+    }
+
+
+def test_get_null_row_information(highly_null_dataframe):
+    expected_highly_null_rows = SeriesWrap(pd.Series([2 / 3, 2 / 3, 2 / 3, 2 / 3]))
+    highly_null_rows = HighlyNullDataCheck.get_null_row_information(
+        highly_null_dataframe, pct_null_row_threshold=0.5
+    )
+    highly_null_rows = SeriesWrap(highly_null_rows)
+    assert highly_null_rows == expected_highly_null_rows
