@@ -61,7 +61,6 @@ def test_binary_init():
     assert clf.random_seed == 42
 
 
-@patch("evalml.pipelines.ClassificationPipeline._decode_targets", return_value=[0, 1])
 @patch(
     "evalml.objectives.BinaryClassificationObjective.decision_function",
     return_value=pd.Series([1, 0]),
@@ -72,7 +71,6 @@ def test_binary_classification_pipeline_predict(
     mock_predict,
     mock_predict_proba,
     mock_obj_decision,
-    mock_decode,
     X_y_binary,
     dummy_binary_pipeline_class,
 ):
@@ -82,55 +80,45 @@ def test_binary_classification_pipeline_predict(
     mock_predict.return_value = predict
     mock_predict_proba.return_value = proba
 
-    mock_objs = [mock_decode, mock_predict]
     X, y = X_y_binary
-    binary_pipeline = dummy_binary_pipeline_class(
-        parameters={"Logistic Regression Classifier": {"n_jobs": 1}}
-    )
+    binary_pipeline = dummy_binary_pipeline_class(parameters={})
     # test no objective passed and no custom threshold uses underlying estimator's predict method
     binary_pipeline.fit(X, y)
     binary_pipeline.predict(X)
-    for mock_obj in mock_objs:
-        mock_obj.assert_called()
-        mock_obj.reset_mock()
+    mock_predict.assert_called()
+    mock_predict.reset_mock()
 
     # test objective passed but no custom threshold uses underlying estimator's predict method
     binary_pipeline.predict(X, "precision")
-    for mock_obj in mock_objs:
-        mock_obj.assert_called()
-        mock_obj.reset_mock()
+    mock_predict.assert_called()
+    mock_predict.reset_mock()
 
-    mock_objs = [mock_decode, mock_predict_proba]
     # test custom threshold set but no objective passed
     binary_pipeline.threshold = 0.6
-    binary_pipeline._encoder.classes_ = [0, 1]
     binary_pipeline.predict(X)
-    for mock_obj in mock_objs:
-        mock_obj.assert_called()
-        mock_obj.reset_mock()
+    mock_predict_proba.assert_called()
+    mock_predict_proba.reset_mock()
     mock_obj_decision.assert_not_called()
     mock_predict.assert_not_called()
 
     # test custom threshold set but no objective passed
     binary_pipeline.threshold = 0.6
     binary_pipeline.predict(X)
-    for mock_obj in mock_objs:
-        mock_obj.assert_called()
-        mock_obj.reset_mock()
+    mock_predict_proba.assert_called()
+    mock_predict_proba.reset_mock()
     mock_obj_decision.assert_not_called()
     mock_predict.assert_not_called()
 
     # test custom threshold set and objective passed
     binary_pipeline.threshold = 0.6
     binary_pipeline.predict(X, "precision")
-    for mock_obj in mock_objs:
-        mock_obj.assert_called()
-        mock_obj.reset_mock()
+    mock_predict_proba.assert_called()
+    mock_predict_proba.reset_mock()
     mock_predict.assert_not_called()
     mock_obj_decision.assert_called()
 
 
-@patch("evalml.pipelines.ComponentGraph._compute_features")
+@patch("evalml.pipelines.ComponentGraph._transform_features")
 def test_binary_predict_pipeline_objective_mismatch(
     mock_transform, X_y_binary, dummy_binary_pipeline_class
 ):
