@@ -4,17 +4,11 @@ import numpy as np
 import pandas as pd
 import pytest
 import woodwork as ww
-from woodwork.logical_types import (
-    Categorical,
-    Datetime,
-    Double,
-    Ordinal,
-    Unknown,
-)
+from woodwork.logical_types import URL, Categorical, Double, Integer, Unknown
 
 from evalml.utils import (
     _convert_numeric_dataset_pandas,
-    _retain_custom_types_and_initalize_woodwork,
+    _schema_is_equal,
     infer_feature_types,
 )
 
@@ -218,55 +212,6 @@ def test_infer_feature_types_raises_invalid_schema_error():
         infer_feature_types(df)
 
 
-def test_ordinal_retains_order_min():
-    features = pd.DataFrame(
-        {
-            "non-ordinal": [0, 1, 2, 3, 4, 5],
-            "ordinal": [0, 1, 2, 2, 1, 0],
-            "categorical": ["red", "white", "blue", "red", "white", "blue"],
-            "datetime": [
-                "2020-09-10",
-                "2020-09-11",
-                "2020-09-12",
-                "2020-09-13",
-                "2020-09-14",
-                "2020-09-15",
-            ],
-        }
-    )
-    user_defined_order = [0, 1, 2]
-    user_defined_dt_format = "%Y-%m-%d"
-    logical_types = {
-        "non-ordinal": "Age",
-        "ordinal": Ordinal(order=user_defined_order),
-        "categorical": Categorical(encoding="Encoding"),
-        "datetime": Datetime(datetime_format=user_defined_dt_format),
-    }
-    features.ww.init(logical_types=logical_types)
-
-    # Ordinal type should now pass through the function without issue and retain the 'order' property
-    ordinal_subset = _retain_custom_types_and_initalize_woodwork(
-        old_logical_types=logical_types, new_dataframe=features[["ordinal"]]
-    )
-    ltypes = ordinal_subset.ww.logical_types
-    assert ltypes["ordinal"].order is not None
-
-    # Datetimes pass the function without issue but should now retain the 'datetime_format' property
-    datetime_subset = _retain_custom_types_and_initalize_woodwork(
-        old_logical_types=logical_types, new_dataframe=features[["datetime"]]
-    )
-    ltypes = datetime_subset.ww.logical_types
-    assert ltypes["datetime"].datetime_format is not None
-
-    # Categorical pass the function but the ltype, as implemented, doesn't ever retain the 'encoding' property,
-    # so we do not expect it here.
-    cat_subset = _retain_custom_types_and_initalize_woodwork(
-        old_logical_types=logical_types, new_dataframe=features[["categorical"]]
-    )
-    ltypes = cat_subset.ww.logical_types
-    assert not hasattr(ltypes["categorical"], "encoding")
-
-
 @pytest.mark.parametrize(
     "null_col,already_inited",
     product(
@@ -311,3 +256,57 @@ def test_infer_feature_types_NA_to_nan(null_col, already_inited):
         assert all([isinstance(x, type(np.nan)) for x in inferred_df["unknown"]])
     else:
         assert all([isinstance(x, str) for x in df["unknown"]])
+
+
+@pytest.mark.parametrize(
+    "logical_types,l_equal",
+    [
+        ({"first": Categorical(), "second": Integer(), "third": Double()}, True),
+        ({"first": Categorical(), "second": Double(), "third": Double()}, True),
+        ({"first": Categorical(), "second": Double(), "third": Categorical()}, False),
+        ({"first": Categorical(), "second": Double(), "third": Unknown()}, False),
+        ({"first": URL(), "second": Double(), "third": Categorical()}, False),
+    ],
+)
+@pytest.mark.parametrize(
+    "semantic_tags,s_equal",
+    [
+        ({"first": [], "second": ["numeric"], "third": ["numeric"]}, True),
+        ({"first": [], "second": ["numeric"], "third": []}, False),
+        ({"first": [], "second": ["numeric"], "third": ["random tag here"]}, False),
+    ],
+)
+def test_schema_is_equal(semantic_tags, s_equal, logical_types, l_equal):
+    schema = ww.table_schema.TableSchema(
+        column_names=["first", "second", "third"],
+        logical_types={"first": Categorical(), "second": Integer(), "third": Double()},
+        semantic_tags={"first": [], "second": ["numeric"], "third": ["numeric"]},
+    )
+    schema_other = ww.table_schema.TableSchema(
+        column_names=["first", "second", "third"],
+        logical_types=logical_types,
+        semantic_tags=semantic_tags,
+    )
+    res = _schema_is_equal(schema, schema_other)
+    assert res == (l_equal and s_equal)
+
+
+def test_schema_is_equal_column_names():
+    schema = ww.table_schema.TableSchema(
+        column_names=["first", "second"],
+        logical_types={"first": Categorical(), "second": Integer()},
+        semantic_tags={"first": [], "second": ["numeric"]},
+    )
+    schema2 = ww.table_schema.TableSchema(
+        column_names=["second", "first"],
+        logical_types={"first": Categorical(), "second": Integer()},
+        semantic_tags={"first": [], "second": ["numeric"]},
+    )
+    assert not _schema_is_equal(schema, schema2)
+
+
+def test_schema_is_equal_fraud(fraud_100):
+    X, y = fraud_100
+    X2 = X.copy()
+    X2.ww.init()
+    assert _schema_is_equal(X.ww.schema, X2.ww.schema)
